class RecipesController < ApplicationController
  before_action :set_recipe, only: [:show, :edit, :update, :destroy]
  before_action :set_form_options, only: [:new, :create, :edit, :update]
  before_action :authenticate_user!, only: [:new, :create, :edit, :update]

  before_filter :require_permission, only: :edit

  # GET /recipes
  # GET /recipes.json
  def index
    @recipes = Recipe.where(user_id: current_user.id)
  end

  # GET /recipes/1
  # GET /recipes/1.json
  def show
  end

  # GET /recipes/new
  def new
    @recipe = Recipe.new
    recipe_item = @recipe.recipe_items.build
  end

  # GET /recipes/1/edit
  def edit
  end

  # POST /recipes
  # POST /recipes.json
  def create
    @recipe = Recipe.new(recipe_params)

    respond_to do |format|
      if @recipe.save
      format.html { redirect_to @recipe, notice: 'Receita salva com sucesso!' }
      format.json { render :show, status: :created, location: @recipe }
      else
      format.html { render :new }
      format.json { render json: @recipe.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /recipes/1
  # PATCH/PUT /recipes/1.json
  def update
    respond_to do |format|
      if @recipe.update(recipe_params)
      format.html { redirect_to @recipe, notice: 'Receita salva com sucesso!' }
      format.json { render :show, status: :ok, location: @recipe }
      else
      format.html { render :edit }
      format.json { render json: @recipe.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /recipes/1
  # DELETE /recipes/1.json
  def destroy
    @recipe.destroy
    respond_to do |format|
      format.html { redirect_to recipes_url, notice: 'Receita excluida com sucesso!' }
      format.json { head :no_content }
    end
  end

  private
  # Use callbacks to share common setup or constraints between actions.
  def set_recipe
    @recipe = Recipe.find(params[:id])
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def recipe_params
    params.require(:recipe).permit(
      :title, :preparation_time, :servings, :directions, :user_id, {:category_ids => []}, 
      recipe_items_attributes: [:id, :ingredient_id, :amount, :measurement_unit_id, :_destroy]
    )
  end

  def require_permission
    if current_user != Recipe.find(params[:id]).user
      redirect_to root_path
    end
  end

  def set_form_options
    @categories = Category.where(user_id: current_user.id)
    @ingredients = Ingredient.where(user_id: current_user.id)
    @measurement_units = MeasurementUnit.all()
  end
end
